@@ -1,5 +1,8 @@
 #import pytz
-from collections import OrderedDict
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 from decimal import Decimal
 from wtforms import (
     BooleanField,
@@ -217,6 +220,8 @@ class FormGenerator(object):
             except UnknownTypeException:
                 if not self.meta.skip_unknown_types:
                     raise
+                else:
+                    continue
 
             if not hasattr(form, column.name):
                 setattr(form, column.name, field)
